@@ -11,8 +11,6 @@ packages_gz_cols <- function()  {
 }
 
 #' @importFrom tools file_ext
-#' @importFrom tibble as_tibble
-#' @importFrom assertthat assert_that
 
 read_packages_file <- function(path, mirror, repodir, platform,
                                type = "standard", meta_path = NA_character_,
@@ -20,7 +18,7 @@ read_packages_file <- function(path, mirror, repodir, platform,
 
   # We might have empty PACKAGES.gz files, we treat them as empty here
   if (file.exists(path) && file.size(path) == 0) {
-    pkgs <- tibble()
+    pkgs <- data_frame()
   } else {
     pkgs <- parse_packages(path)
   }
@@ -34,18 +32,22 @@ read_packages_file <- function(path, mirror, repodir, platform,
   names(pkgs) <- tolower(names(pkgs))
 
   ## If Windows, then we need to check which binary has i386 support
-  if (platform %in% c("i386+x86_64-w64-mingw32",
-                      "i386-w64-mingw32", "x86_64-w64-mingw32")) {
-    pkgs$platform <- "i386+x86_64-w64-mingw32"
-    if ("archs" %in% colnames(pkgs)) {
-      archs <- gsub(" ", "", fixed = TRUE, pkgs$archs)
-      p32 <- !is.na(archs) & archs == "i386"
-      pkgs$platform[p32] <- "i386-w64-mingw32"
-      p64 <- !is.na(archs) & archs == "x64"
-      pkgs$platform[p64] <- "x86_64-w64-mingw32"
+  if (nrow(pkgs)) {
+    if (platform %in% c("i386+x86_64-w64-mingw32",
+                        "i386-w64-mingw32", "x86_64-w64-mingw32")) {
+      pkgs$platform <- "i386+x86_64-w64-mingw32"
+      if ("archs" %in% colnames(pkgs)) {
+        archs <- gsub(" ", "", fixed = TRUE, pkgs$archs)
+        p32 <- !is.na(archs) & archs == "i386"
+        pkgs$platform[p32] <- "i386-w64-mingw32"
+        p64 <- !is.na(archs) & archs == "x64"
+        pkgs$platform[p64] <- "x86_64-w64-mingw32"
+      }
+    } else {
+      pkgs$platform <- if (nrow(pkgs)) platform
     }
   } else {
-    pkgs$platform <- platform
+    pkgs$platform <- character()
   }
 
   if (! "needscompilation" %in% names(pkgs)) {
@@ -72,7 +74,8 @@ read_packages_file <- function(path, mirror, repodir, platform,
     platform, repodir, pkgs$package, pkgs$version, pkgs[["file"]], pkgs[["path"]])
   pkgs$mirror <- if (nrow(pkgs)) mirror else character()
   pkgs$sources <- packages_make_sources(
-    mirror, platform, pkgs$target, repodir, pkgs$package, pkgs$version, type)
+    mirror, platform, pkgs$target, repodir, pkgs$package, pkgs$version,
+    type, pkgs$downloadurl)
 
   if (!is.null(meta)) {
     metatarget <- paste0(repodir, "/", meta$file)
@@ -132,12 +135,10 @@ read_metadata_file <- function(path) {
   }), error = function(e) NULL)
 }
 
-#' @importFrom tibble tibble
-
 packages_parse_deps <- function(pkgs) {
   no_pkgs <- nrow(pkgs)
   cols <- intersect(colnames(pkgs), tolower(dep_types()))
-  ## as.character is for empty tibbles, e.g. from empty BioC repos
+  ## as.character is for empty data frame, e.g. from empty BioC repos
   deps <- as.character(unlist(pkgs[, cols], use.names = FALSE))
   nna <- which(!is.na(deps))
   if (length(nna)) {
@@ -157,13 +158,15 @@ packages_parse_deps <- function(pkgs) {
     parsed <- parsed[order(parsed$idx), ]
 
   } else {
-    parsed <- tibble(upstream = character(),
-                     idx = integer(),
-                     ref = character(),
-                     type = character(),
-                     package = character(),
-                     version = character(),
-                     op = character())
+    parsed <- data_frame(
+      upstream = character(),
+      idx = integer(),
+      ref = character(),
+      type = character(),
+      package = character(),
+      version = character(),
+      op = character()
+    )
   }
 
   parsed
@@ -205,7 +208,7 @@ packages_make_target <- function(platform, repodir, package, version,
 }
 
 packages_make_sources <- function(mirror, platform, target, repodir,
-                                  package, version, type) {
+                                  package, version, type, downloadurl) {
 
   assert_that(
     is_string(mirror),
@@ -213,14 +216,16 @@ packages_make_sources <- function(mirror, platform, target, repodir,
     is_character(target),
     is_string(repodir),
     is_character(package),
-    is_character(version), length(version) == length(package))
+    is_character(version), length(version) == length(package),
+    is.null(downloadurl) || is.character(downloadurl)
+  )
 
   if (!length(package)) return(list())
 
   url <- paste0(mirror, "/", target)
 
   os <- parse_platform(platform)$os
-  if (type == "cran" && !is.na(os) && grepl("^darwin", os)) {
+  srcs <- if (type == "cran" && !is.na(os) && grepl("^darwin", os)) {
     macurl <- paste0("https://mac.r-project.org/", target)
     zip_vecs(url, macurl)
 
@@ -232,6 +237,12 @@ packages_make_sources <- function(mirror, platform, target, repodir,
   } else {
     as.list(url)
   }
+
+  if (!is.null(downloadurl)) {
+    srcs[!is.na(downloadurl)] <- as.list(na_omit(downloadurl))
+  }
+
+  srcs
 }
 
 merge_packages_data <- function(..., .list = list()) {
@@ -256,13 +267,13 @@ rbind_expand <- function(..., .list = list()) {
   for (i in seq_along(data)) {
     miss_cols <- setdiff(cols, colnames(data[[i]]))
     if (length(miss_cols)) {
-      na_df <- as_tibble(structure(
+      na_df <- as_data_frame(structure(
         replicate(
           length(miss_cols),
           if (nrow(data[[i]])) NA else logical(),
           simplify = FALSE),
         names = miss_cols))
-      data[[i]] <- as_tibble(cbind(data[[i]], na_df))
+      data[[i]] <- as_data_frame(cbind(data[[i]], na_df))
     }
   }
 
